\name{krige.conv}

\alias{krige.conv}
\alias{krige.control}
%- Also NEED an `\alias' for EACH other topic documented here.

\title{Spatial Prediction - Conventional Kriging}


\description{
  This function performs spatial prediction for fixed covariance
  parameters, using a global neighborhood.
  
  Options corresponding to the following kriging
  types: \emph{SK} (simple kriging), \emph{OK} (ordinary kriging),
    \emph{KTE} (external trend kriging), \emph{UK} (universal kriging). 
  
}

\usage{
krige.conv(geodata, coords = geodata$coords, data = geodata$data, 
           locations,
           krige = krige.control(type.krige, beta = NULL,
                     trend.d, trend.l, cov.model, cov.pars,
                     kappa = 0.5, nugget = 0, micro.scale = 0,
                     dist.epsilon = 1e-10, aniso.pars = NULL, 
                     lambda = 1, signal = FALSE,
                     n.samples.backtransform = 500, n.sim = 0),
           messages.screen = TRUE) 
}

%- maybe also `usage' for other objects documented here.

\arguments{
  \item{geodata}{a list containing elements \code{coords} and
    \code{data} as described next. Typically an object of the \code{\link{class}}
    \code{"geodata"} - a \bold{geoR} data-set. If not provided the arguments
    \code{coords} and \code{data} must be provided instead.  }
  \item{coords}{an \eqn{n \times 2}{n x 2} matrix where each row have the 2-D
    coordinates of the \eqn{n} data locations.
    By default it takes the
    component \code{coords} of the argument \code{geodata}, if provided.  }
  \item{data}{a vector with \emph{n} data values. By default it takes the
    component \code{data} of the argument \code{geodata}, if provided.}
  \item{locations}{an \eqn{N \times 2}{N x 2} matrix or data-frame with the 2-D
    coordinates of the \eqn{N} locations to be predicted.  }
  \item{krige}{defines the model components and several options for
    kriging. \cr ATTENTION: the argument \code{cov.pars} is obligatory whilst
    the others have default options.
    See section DETAILS below.  }
  \item{messages.screen}{logical. Indicates
    whether or not messages are printed on the screen (or other output device)
    while the function is running.}
}


\details{
  One of the different types of kriging (\emph{SK}, \emph{OK}, \emph{UK}, \emph{KTE})
  is performed according to the input options.
  Defaults corresponds to ordinary kriging.
  
  \bold{Arguments for \code{krige = krige.control(\dots)} :} 

  \itemize{
    \item{type.krige}{type of kriging to be performed. Options are
      \code{"SK", "OK"} corresponding to simple or ordinary
      kriging. Kriging with external trend (universal kriging) can be
      defined setting \code{type.krige = "OK"} and specifying the
      trend model using the arguments \code{trend.d} and
      \code{trend.l}.  } 
    \item{beta}{value of the mean (vector) parameter. Only used if \code{type.krige="SK"}.}  
    \item{trend.d}{information about the trend (covariates) values at the data
      locations. Possible values are:
      \cr
      \code{"cte"} - model with constant mean, i.e. no trend
      \cr
      \code{"1st"} - trend is defined as a first degree polynomial on the coordinates
      \cr
      \code{"2nd"} - trend is defined as a second degree polynomial on the
      coordinates
      \cr a formula of the type \code{~X}, where \code{X} is a matrix with covariates (external trend)
      at data locations.
      \cr
      Defaults to \code{"cte"}.  }
    \item{trend.l}{Specifies the trend (covariate) at prediction
      locations. It must be the same type as defined in \code{trend.d}.
      Only used if prediction locations are provided in the argument
      \code{locations}.  }
    \item{cov.model}{model for the correlation function. See options in the
      function call and/or documentation for the function
      \code{\link{cov.spatial}}.  }
    \item{cov.pars}{a vector with 2 elements or an \eqn{n \times 2}{n x
	2} matrix with the covariance parameters \eqn{\sigma^2}{sigma^2}
      (partial sill)  and \eqn{\phi}{phi} (range parameter).
      If a vector, the sill must be the first element and the range is the second. If a matrix,
      corresponding to a model with several structures, the sill values
      are placed in the first column and the range values in the second
      column.  }  
    \item{kappa}{additional parameter needed the the following correlation
      functions: (\code{"matern"},\cr  \code{"powered.exponential"}, \code{"gneiting"} and
      \code{"gneiting.matern"}). For more details see documentation for the
      function \code{\link{cov.spatial}}.  }
    \item{nugget}{the value of the nugget variance. Defaults to zero.  }
    \item{micro.scale}{micro-scale variance. If different from zero, the
      nugget variance is divided into 2 terms: \emph{micro-scale variance}
      and \emph{measurement error}. This might affect the precision of the estimates.
      In practice, these two are usually indistinguishable but the
      distinction can be made here if justifiable.  } 
    \item{dist.epsilon}{a distance such that points closer the the value
      of \code{dist.epsilon} are considered co-located.  }
    \item{aniso.pars}{fixed parameters for geometric anisotropy
      correction. If \code{aniso.pars = FALSE} no correction is made otherwise
      a vector with 2 values, anisotropy angle and ratio of ranges,
      must be provided. Anisotropy correction consists of a
      transformation in the data and prediction coordinates performed
      by the function \code{\link{coords.aniso}}.}
    \item{lambda}{Box-Cox transformation parameter. If \eqn{\lambda =
	1}{lambda = 1} no transformation is used, otherwise the Box-Cox
      data transformation is performed before the analysis.
      The kriging results are returned in the same scale as for the original data.
      If \eqn{\lambda = 0}{lambda = 0} the log-transformation is performed.
      If \eqn{\lambda < 0}{lambda < 0} the mean predictor doesn't make sense
      (the resulting distribution has no expectation).}
    \item{signal}{logical. If \code{TRUE} the signal is predict, otherwise the
      variable is predict. If no transformation is performed the
      expectations are the same in both cases and the difference is only in
      values of the kriging variance, if the value of the nugget is
      different from zero.  }
    \item{n.samples.backtransform}{When transformations are used
      (specified by the argument \code{lambda}), back-transformations
      are usually performed by sampling the predictive distribution and
      back-transforming the sampled values. The exceptions are for
      \eqn{\lambda = 0}{lambda = 0} (log-transformation)  and
      \eqn{\lambda = 1}{lambda = 1} (no transformation). 
      This option defines how many samples are taken to perform the
      back-transformation.}
    \item{n.sim}{optional. Number of simulations to be drawn from the
      posterior distribution. If \code{n.sim} is provided, samples are
      taken from the predictive distribution. This corresponds to
      realizations of conditional simulations, given the data.}
    
  }
}


\value{
  An object of the \code{\link{class}} \code{kriging} which is a  list
  with the following components:
  
  \item{predict}{a vector with predicted value at the prediction
    locations.  }
  \item{krige.var}{a vector with predicted variances at the prediction
    locations.  }
  \item{beta.est}{estimates of the \eqn{\beta}{beta} parameter
    implicitly made during the kriging procedure. Not used if
    \code{type.krige = "SK"}.  }
  \item{simulations}{an \eqn{ni \times n.sim}{ni x n.sim} matrix where \eqn{ni} is the
    number of prediction locations. Each column corresponds to a
    conditional simulation of the predictive distribution.
    Only returned if \code{n.sim > 0}.  }
  \item{message}{messages about the type of prediction performed.  }
  \item{call}{the function call.  }
  
}


\references{
  Further information about \bold{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}

%\note{}

\author{
  Paulo J. Ribeiro Jr. \email{paulojus@est.ufpr.br} \cr
  Peter J. Diggle \email{p.diggle@lancaster.ac.uk}.
}

\seealso{\code{\link{image.kriging}}, \code{\link{krige.bayes}}, \code{\link{ksline}}.
}


\examples{
if(is.R()) data(s100) 
loci <- expand.grid(seq(0,1,l=31), seq(0,1,l=31))
kc <- krige.conv(s100, loc=loci,
                 krige=krige.control(cov.pars=c(1, .25)))
par(mfrow=c(1,2))
image.kriging(kc, loc=loci, main="kriging estimates")
image.kriging(kc, loc=loci, val=sqrt(kc$krige.var),
              main="kriging std. errors")

}


\keyword{spatial}

